@@ -1,6 +1,8 @@
 """
 Collector plugin for DNF packages
 """
+from __future__ import annotations
+
 import fnmatch
 import os
 import shutil
@@ -9,23 +11,23 @@ from configparser import ConfigParser
 from os import PathLike
 from pathlib import Path
 from time import sleep
-from typing import Dict, List, Optional, Union
 from urllib.parse import quote_plus, urljoin, urlparse
 
 import requests
 
-from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 from packageurl import PackageURL
 from requests.auth import HTTPBasicAuth
 
+import hoppr.net
+
 from hoppr import __version__
 from hoppr.base_plugins.collector import BatchCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_process, hoppr_rerunner
-from hoppr.configs.credentials import Credentials
-from hoppr.context import Context
 from hoppr.exceptions import HopprPluginError
-from hoppr.hoppr_types.cred_object import CredObject
-from hoppr.hoppr_types.purl_type import PurlType
+from hoppr.models import HopprContext
+from hoppr.models.credentials import Credentials
+from hoppr.models.types import PurlType
+from hoppr.models.manifest import Component
 from hoppr.result import Result
 
 
@@ -40,6 +42,27 @@ def _artifact_string(purl: PackageURL) -> str:
     return artifact_string
 
 
+def _is_rpm_repo(repo_url: str) -> bool:
+    url = urljoin(repo_url + "/", "repodata/repomd.xml")
+
+    basic_auth = None
+    creds = Credentials.find(repo_url)
+    if creds is not None:
+        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password.get_secret_value())
+
+    for attempt in range(3):
+        if attempt > 0:
+            sleep(5)
+
+        resp = requests.get(url, auth=basic_auth, allow_redirects=False, stream=True, verify=True, timeout=60)
+        if resp.status_code < 300:
+            return True
+        if resp.status_code < 500:
+            return False
+
+    return False
+
+
 def _repo_proxy(url: str) -> str:
     proxy = os.getenv("https_proxy", "_none_")
     no_proxy_urls = [item for item in os.getenv("no_proxy", "").split(",") if item != ""]
@@ -54,51 +77,27 @@ def _repo_proxy(url: str) -> str:
     return proxy
 
 
-def _is_rpm_repo(repo_url: str, creds: Optional[CredObject]):
-
-    url = urljoin(repo_url + "/", "repodata/repomd.xml")
-
-    basic_auth = None
-    if creds is not None:
-        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password)
-
-    for attempt in range(3):
-        if attempt > 0:
-            sleep(5)
-
-        resp = requests.get(url, auth=basic_auth, allow_redirects=False, stream=True, verify=True, timeout=60)
-        if resp.status_code < 300:
-            return True
-        if resp.status_code < 500:
-            return False
-
-    return False
-
-
 class CollectDnfPlugin(BatchCollectorPlugin):
     """
     Collector plugin for DNF packages
     """
 
-    required_commands: List[str] = ["dnf"]
-    supported_purl_types: List[str] = ["rpm"]
-    products: List[str] = ["rpm/*"]
+    required_commands: list[str] = ["dnf"]
+    supported_purl_types: list[str] = ["rpm"]
+    products: list[str] = ["rpm/*"]
 
     def __init__(
         self,
-        context: Context,
-        config: Optional[Dict] = None,
-        config_file: Union[str, PathLike] = Path.cwd().joinpath(".hoppr-dnf", "dnf.conf"),
+        context: HopprContext,
+        config: dict | None = None,
+        config_file: str | PathLike = Path.cwd() / ".hoppr-dnf" / "dnf.conf",
     ) -> None:
-        super().__init__(
-            context=context,
-            config=config,
-        )
+        super().__init__(context=context, config=config)
 
-        self.password_list: List[str] = []
-        self.manifest_repos: List[str] = []
+        self.password_list: list[str] = []
+        self.manifest_repos: list[str] = []
 
-        for repo in self.context.manifest.consolidated_repositories[PurlType.RPM]:
+        for repo in self.context.repositories[PurlType.RPM]:
             self.manifest_repos.append(repo.url)
 
         self.config_file = Path(config_file)
@@ -133,7 +132,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
 
         return found_url
 
-    def _get_found_repo(self, found_url: str) -> Union[str, None]:
+    def _get_found_repo(self, found_url: str) -> str | None:
         """
         Identify the repository associated with the specified URL
         """
@@ -151,11 +150,11 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         repo_config = ConfigParser()
         repo_config["main"] = dict(cachedir=f"{self.config_file.parent / 'cache'}")
 
-        for idx, repo in enumerate(self.context.manifest.consolidated_repositories[PurlType.RPM]):
+        for idx, repo in enumerate(self.context.repositories[PurlType.RPM]):
             temp_repo = f"hoppr-tmp-{idx}"
-            creds = Credentials.find_credentials(repo.url)
+            creds = Credentials.find(repo.url)
 
-            if not _is_rpm_repo(repo.url, creds):
+            if not _is_rpm_repo(repo.url):
                 self.get_logger().warning(
                     f"Repo {repo.url} is not an RPM repository (repomd.xml file not found), will not be searched"
                 )
@@ -221,8 +220,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         Copy a component to the local collection directory structure
         """
 
-        purl = PackageURL.from_string(comp.purl)
-        artifact = _artifact_string(purl)  # type: ignore
+        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
 
         self.get_logger().info(msg=f"Copying DNF package from {purl}", indent_level=2)
 
@@ -249,14 +247,21 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         target_dir = self.directory_for(purl.type, repo, subdir=str(subdir))
 
         # Download the RPM file to the new directory
-        command = [*self.base_command, "download", f"--destdir={target_dir}", artifact]
-        run_result = self.run_command(command, self.password_list)
+        response = hoppr.net.download_file(
+            url=found_url, dest=str(target_dir / found_url_path.name), creds=Credentials.find(url=repo)
+        )
+        result = Result.from_http_response(response)
 
-        if run_result.returncode != 0:
-            msg = f"Failed to download DNF artifact {purl.name} version {purl.version}"
+        if result.is_retry():
+            msg = f"Failed to download DNF artifact {purl.name} version {purl.version} from {found_url}"
+            self.get_logger().error(msg=msg, indent_level=2)
             return Result.retry(message=msg)
 
-        return Result.success()
+        if result.is_success():
+            self.set_collection_params(comp, repo, target_dir)
+            result = Result.success(result.message, return_obj=comp)
+
+        return result
 
     @hoppr_process
     def post_stage_process(self) -> Result:
