@@ -1,25 +1,22 @@
 """
 Collector plugin for helm charts
 """
+from __future__ import annotations
+
 import re
 
-from copy import deepcopy
 from pathlib import Path
-from typing import Dict, Optional
 from urllib.parse import urljoin
 
-from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
-from packageurl import PackageURL  # type: ignore
+from packageurl import PackageURL
 
 from hoppr import __version__, utils
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.context import Context
 from hoppr.exceptions import HopprLoadDataError
-from hoppr.flatten_sboms import flatten_sboms
-from hoppr.hoppr_types.cred_object import CredObject
-from hoppr.hoppr_types.manifest_file_content import Repository
-from hoppr.hoppr_types.purl_type import PurlType
+from hoppr.models import HopprContext
+from hoppr.models.credentials import CredentialRequiredService
+from hoppr.models.manifest import Component
 from hoppr.result import Result
 
 
@@ -31,11 +28,12 @@ class CollectHelmPlugin(SerialCollectorPlugin):
     supported_purl_types = ["helm"]
     required_commands = ["helm"]
     products: list[str] = ["helm/*"]
+    system_repositories: list[str] = []
 
     def get_version(self) -> str:  # pylint: disable=duplicate-code
         return __version__
 
-    def __init__(self, context: Context, config: Optional[Dict] = None) -> None:
+    def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
 
         self.create_logger()
@@ -59,26 +57,16 @@ class CollectHelmPlugin(SerialCollectorPlugin):
             except HopprLoadDataError as ex:
                 self.get_logger().warning(msg=f"Unable to parse Helm repositories file ({system_repos_file}): '{ex}'")
 
-            self.context.manifest.consolidated_repositories[PurlType.HELM].extend(
-                [Repository(url=repo["url"], description=repo["name"]) for repo in system_repos]
-            )
-
-            self.context.consolidated_sbom = flatten_sboms(self.context.manifest)
-            self.context.delivered_sbom = deepcopy(self.context.consolidated_sbom)
+            self.system_repositories.extend(repo["url"] for repo in system_repos)
 
     @hoppr_rerunner
     # pylint: disable=duplicate-code
-    def collect(self, comp: Component, repo_url: str, creds: Optional[CredObject] = None):
+    def collect(self, comp: Component, repo_url: str, creds: CredentialRequiredService | None = None):
         """
         Collect helm chart
         """
 
-        purl = PackageURL.from_string(comp.purl)
-
-        if self.context.strict_repos:
-            helm_result = self.check_purl_specified_url(purl, repo_url)  # type: ignore
-            if not helm_result.is_success():
-                return helm_result
+        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
 
         if not re.match(pattern="^.*/$", string=repo_url):
             repo_url = f"{repo_url}/"
@@ -111,16 +99,18 @@ class CollectHelmPlugin(SerialCollectorPlugin):
                     "--username",
                     creds.username,
                     "--password",
-                    creds.password,
+                    creds.password.get_secret_value(),
                 ]
 
-                password_list = [creds.password]
+                password_list = [creds.password.get_secret_value()]
 
             run_result = self.run_command(command, password_list)
 
             if run_result.returncode == 0:
                 self.get_logger().info(f"Complete helm chart artifact copy for {purl.name} version {purl.version}")
-                return Result.success()
+                self.set_collection_params(comp, repo_url, target_dir)
+
+                return Result.success(return_obj=comp)
 
         msg = f"Failed to download {purl.name} version {purl.version} helm chart"
         self.get_logger().debug(msg=msg, indent_level=2)
