@@ -1,14 +1,14 @@
 """
 Collector plugin to copy artifacts using the Nexus API
 """
+from __future__ import annotations
 
 import json
-import os
 import re
 
 from pathlib import Path
 from time import sleep
-from typing import Any, Dict, Optional
+from typing import Any
 from urllib.parse import urljoin, urlparse
 
 import requests
@@ -19,8 +19,9 @@ from requests.auth import HTTPBasicAuth
 from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.context import Context
-from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.models import HopprContext
+from hoppr.models.credentials import CredentialRequiredService
+from hoppr.models.types import PurlType
 from hoppr.net import download_file
 from hoppr.result import Result
 
@@ -33,7 +34,7 @@ class CollectNexusSearch(SerialCollectorPlugin):
     def get_version(self) -> str:  # pylint: disable=duplicate-code
         return __version__
 
-    def __init__(self, context: Context, config: Optional[Dict] = None) -> None:
+    def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
         if self.config is not None:
             if "purl_types" in self.config:
@@ -54,23 +55,21 @@ class CollectNexusSearch(SerialCollectorPlugin):
         return purl_type not in ["git", "github", "gitlab"]
 
     @hoppr_rerunner
-    def collect(self, comp: Any, repo_url: str, creds: CredObject = None) -> Result:
+    def collect(self, comp: Any, repo_url: str, creds: CredentialRequiredService | None = None) -> Result:
         """
         Collect artifact from Nexus
         """
 
-        auth: Optional[HTTPBasicAuth] = None
+        auth: HTTPBasicAuth | None = None
         if creds is not None:
-            auth = HTTPBasicAuth(username=creds.username, password=creds.password)
+            auth = HTTPBasicAuth(username=creds.username, password=creds.password.get_secret_value())
 
-        if not CollectNexusSearch.is_nexus_instance(repo_url, auth):
-            return Result.fail(f"{repo_url} is not a Nexus instance")
+        nexus_url = self._parse_nexus_url(repo_url)[0]
 
-        purl = PackageURL.from_string(comp.purl)
+        if not CollectNexusSearch.is_nexus_instance(nexus_url, auth):
+            return Result.fail(f"{nexus_url} is not a Nexus instance")
 
-        nexus_result = self.check_purl_specified_url(purl, repo_url)
-        if not nexus_result.is_success():
-            return nexus_result
+        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
 
         source_urls = CollectNexusSearch.get_download_urls(purl, repo_url, auth)
         if len(source_urls) == 0:
@@ -88,7 +87,7 @@ class CollectNexusSearch(SerialCollectorPlugin):
 
             file_name = Path(urlparse(source_url).path).parts[-1]
 
-            response = download_file(source_url, os.path.join(target_dir, file_name), creds)
+            response = download_file(source_url, str(target_dir / file_name))
             nexus_result = Result.from_http_response(response)
 
             self.get_logger().info(f"Download Result: {nexus_result}", indent_level=3)
@@ -96,7 +95,19 @@ class CollectNexusSearch(SerialCollectorPlugin):
             if not nexus_result.is_success():
                 return nexus_result
 
-        return Result.success()
+        self.set_collection_params(comp, repo_url, target_dir)
+        return Result.success(return_obj=comp)
+
+    @staticmethod
+    def _parse_nexus_url(repo_url: str) -> tuple[str, str | None]:
+        nexus_url = repo_url
+        nexus_repo = None
+        repo_specified = re.search(r"(https?://.*?)/repository/(.*?)(/.*)?$", repo_url)
+        if repo_specified:
+            nexus_url = repo_specified.group(1)
+            nexus_repo = repo_specified.group(2)
+
+        return (nexus_url, nexus_repo)
 
     def _directory_for_nexus(self, purl: PackageURL, url: str) -> Path:
         repo_match = re.search(r"(.*?/repository/.*?)(/.*)?/(.*)", url)
@@ -118,12 +129,12 @@ class CollectNexusSearch(SerialCollectorPlugin):
         return target_dir
 
     @staticmethod
-    def is_nexus_instance(repo_url: str, auth: Optional[HTTPBasicAuth] = None) -> bool:
+    def is_nexus_instance(repo_url: str, auth: HTTPBasicAuth | None = None) -> bool:
         """
         Checks whether or not the repo_url refers to a Nexus instance
         """
 
-        test_url = urljoin(repo_url, "service/rest/v1/status")
+        test_url = urljoin(repo_url + "/", "service/rest/v1/status")
 
         for attempt in range(3):
             if attempt > 0:
@@ -146,11 +157,13 @@ class CollectNexusSearch(SerialCollectorPlugin):
         return False
 
     @staticmethod
-    def get_download_urls(purl: PackageURL, repo_url: str, auth: Optional[HTTPBasicAuth] = None) -> list[str]:
+    def get_download_urls(purl: PackageURL, repo_url: str, auth: HTTPBasicAuth | None = None) -> list[str]:
         """
         Retrieves all urls to be retrieved from Nexus for this component
         """
-        search_url = urljoin(repo_url, "service/rest/v1/search/assets")
+        nexus_url, nexus_repo = CollectNexusSearch._parse_nexus_url(repo_url)
+
+        search_url = urljoin(nexus_url + "/", "service/rest/v1/search/assets")
 
         additional_search_params: list[dict] = [{}]
         nexus_format = purl.type
@@ -180,6 +193,9 @@ class CollectNexusSearch(SerialCollectorPlugin):
         if purl.version is not None:
             base_params["version"] = purl.version
 
+        if nexus_repo is not None:
+            base_params["repository"] = nexus_repo
+
         url_list = []
         for extra_search_parms in additional_search_params:
             response = requests.get(
@@ -191,9 +207,27 @@ class CollectNexusSearch(SerialCollectorPlugin):
                 timeout=60,
                 params=base_params | extra_search_parms,
             )
+
             if response.status_code < 300:
                 search_result = json.loads(response.content)
-                if len(search_result["items"]) > 0:
-                    url_list.append(search_result["items"][0]["downloadUrl"])
+                for item in search_result["items"]:
+                    if item["downloadUrl"].startswith(repo_url):
+                        url_list.append(item["downloadUrl"])
+                        break
 
         return url_list
+
+    @classmethod
+    def get_attestation_products(cls, config: dict | None = None) -> list[str]:
+
+        products = []
+        if config is not None and "purl_types" in config:
+            for purl_type in config["purl_types"]:
+                products.append(purl_type + "/*")
+
+        else:
+            for purl_type in PurlType:
+                if str(purl_type) not in ["git", "github", "gitlab"]:
+                    products.append(str(purl_type) + "/*")
+
+        return products
