@@ -10,14 +10,14 @@ import sys
 from subprocess import CalledProcessError
 from urllib.parse import ParseResult, urljoin, urlparse
 
-from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 from packageurl import PackageURL
 
 from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.context import Context
-from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.models import HopprContext
+from hoppr.models.credentials import CredentialRequiredService
+from hoppr.models.manifest import Component
 from hoppr.result import Result
 
 
@@ -34,7 +34,7 @@ class CollectPypiPlugin(SerialCollectorPlugin):
     def get_version(self) -> str:  # pylint: disable=duplicate-code
         return __version__
 
-    def __init__(self, context: Context, config: dict | None = None) -> None:
+    def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
 
         self.manifest_repos: list[str] = []
@@ -68,7 +68,7 @@ class CollectPypiPlugin(SerialCollectorPlugin):
         return self._run_cmd_wrapper(command, password_list, "--no-binary=:all:", "source", log_if_error)
 
     @hoppr_rerunner
-    def collect(self, comp: Component, repo_url: str, creds: CredObject | None = None) -> Result:
+    def collect(self, comp: Component, repo_url: str, creds: CredentialRequiredService | None = None) -> Result:
         """
         Copy a component to the local collection directory structure
         """
@@ -76,9 +76,6 @@ class CollectPypiPlugin(SerialCollectorPlugin):
             return Result.fail(message="The pip package was not found. Please install and try again.")
 
         purl = PackageURL.from_string(comp.purl)
-        result = self.check_purl_specified_url(purl, repo_url)  # type: ignore
-        if not result.is_success():
-            return result
 
         source_url = repo_url
         if not re.match(pattern="^.*simple/?$", string=source_url):
@@ -88,9 +85,9 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         if creds is not None:
             parsed_url = urlparse(url=source_url)._asdict()
-            parsed_url["netloc"] = f"{creds.username}:{creds.password}@{parsed_url['netloc']}"
+            parsed_url["netloc"] = f"{creds.username}:{creds.password.get_secret_value()}@{parsed_url['netloc']}"
             source_url = ParseResult(**parsed_url).geturl()
-            password_list = [creds.password]
+            password_list = [creds.password.get_secret_value()]
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.name}_{purl.version}")
 
@@ -113,8 +110,10 @@ class CollectPypiPlugin(SerialCollectorPlugin):
         base_error_msg = f"Failed to download {purl.name} version {purl.version}"
 
         if self.collect_binary_only(command, password_list, base_error_msg):  # pylint: disable=no-else-return
-            return Result.success()
+            self.set_collection_params(comp, repo_url, target_dir)
+            return Result.success(return_obj=comp)
         elif self.collect_source(command, password_list, base_error_msg):  # pylint: disable=no-else-return
-            return Result.success()
+            self.set_collection_params(comp, repo_url, target_dir)
+            return Result.success(return_obj=comp)
         else:
             return Result.retry(f"{base_error_msg} as either binary or source.")
