@@ -8,12 +8,12 @@ from pathlib import Path
 from typing import Any, List
 from urllib.parse import unquote, urljoin, urlparse
 
-from packageurl import PackageURL  # type: ignore
+from packageurl import PackageURL
 
 from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.models.credentials import CredentialRequiredService
 from hoppr.net import download_file
 from hoppr.result import Result
 
@@ -30,20 +30,20 @@ class CollectRawPlugin(SerialCollectorPlugin):
         return __version__
 
     @hoppr_rerunner
-    def collect(self, comp: Any, repo_url: str, creds: CredObject = None):
+    def collect(self, comp: Any, repo_url: str, creds: CredentialRequiredService | None = None):
         """
         Copy a component to the local collection directory structure
         """
+        if not repo_url.endswith("/"):
+            repo_url = f"{repo_url}/"
+
         source_url = urlparse(repo_url)
 
         purl = PackageURL.from_string(comp.purl)
-        result = self.check_purl_specified_url(purl, repo_url)
-        if not result.is_success():
-            return result
 
         subdir = None
         if purl.namespace is not None:
-            source_url = urlparse(urljoin(source_url.geturl() + "/", purl.namespace))
+            source_url = urlparse(urljoin(repo_url, purl.namespace))
             subdir = unquote(purl.namespace)
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=subdir)
@@ -51,23 +51,12 @@ class CollectRawPlugin(SerialCollectorPlugin):
         file_name = unquote(purl.name)
 
         if source_url.scheme == "file":
-            source_url = urlparse(repo_url + (purl.namespace or ""))
-            source_file = Path(source_url.path, file_name).expanduser()
+            repo_path = Path(repo_url.removeprefix("file:").removeprefix("//"))
+            source_file = (repo_path / (purl.namespace or "") / file_name).expanduser()
 
-            self.get_logger().info(
-                msg="Copying component:",
-                indent_level=2,
-            )
-
-            self.get_logger().info(
-                msg=f"source: {source_file}",
-                indent_level=3,
-            )
-
-            self.get_logger().info(
-                msg=f"destination: {target_dir.joinpath(file_name)}",
-                indent_level=3,
-            )
+            self.get_logger().info(msg="Copying component:", indent_level=2)
+            self.get_logger().info(msg=f"source: {source_file}", indent_level=3)
+            self.get_logger().info(msg=f"destination: {target_dir.joinpath(file_name)}", indent_level=3)
 
             if not source_file.is_file():
                 msg = f"Unable to locate file {source_file}, skipping remaining attempts"
@@ -75,30 +64,26 @@ class CollectRawPlugin(SerialCollectorPlugin):
                 return Result.fail(message=msg)
 
             shutil.copy(source_file, target_dir)
-            return Result.success()
+
+            self.set_collection_params(comp, repo_url, target_dir)
+            return Result.success(return_obj=comp)
 
         download_url = urljoin(source_url.geturl() + "/", file_name)
 
-        self.get_logger().info(
-            msg="Downloading file:",
-            indent_level=2,
-        )
+        self.get_logger().info(msg="Downloading file:", indent_level=2)
+        self.get_logger().info(msg=f"source: {download_url}", indent_level=3)
+        self.get_logger().info(msg=f"destination: {target_dir.joinpath(file_name)}", indent_level=3)
 
-        self.get_logger().info(
-            msg=f"source: {download_url}",
-            indent_level=3,
-        )
-
-        self.get_logger().info(
-            msg=f"destination: {target_dir.joinpath(file_name)}",
-            indent_level=3,
-        )
-
-        response = download_file(download_url, target_dir.joinpath(file_name), creds)
+        response = download_file(download_url, str(target_dir / file_name), creds)
         result = Result.from_http_response(response)
 
         if result.is_fail():
             msg = f"Unable to download from {download_url}, skipping remaining attempts"
             self.get_logger().error(msg=msg, indent_level=2)
 
-        return result
+        if not result.is_success():
+            return result
+
+        self.set_collection_params(comp, repo_url, target_dir)
+
+        return Result.success(return_obj=comp)
