@@ -3,9 +3,6 @@ Enumeration to indicate how a plugin may change a BOM
 """
 from __future__ import annotations
 
-import math
-
-from enum import Enum
 from typing import Any
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
@@ -36,31 +33,6 @@ class BomAccess(YamlIntEnum):
                 return isinstance(obj, Bom)
 
 
-class ComponentCoverage(Enum):
-    """
-    Enumeration to indicate how often each component should be processed
-    """
-
-    # pylint: disable=duplicate-code
-    OPTIONAL = (0, math.inf)
-    EXACTLY_ONCE = (1, 1)
-    AT_LEAST_ONCE = (1, math.inf)
-    NO_MORE_THAN_ONCE = (0, 1)
-
-    def __init__(self, min_allowed: int, max_allowed: int):
-        self.min_value = min_allowed
-        self.max_value = max_allowed
-
-    def __str__(self) -> str:
-        return str(self.name)
-
-    def accepts_count(self, count: int) -> bool:
-        """
-        Identifies whether a specified count is acceptable for this coverage value
-        """
-        return self.min_value <= count <= self.max_value
-
-
 class PurlType(YamlStrEnum):
     """
     Enumeration of supported purl types
@@ -78,4 +50,5 @@ class PurlType(YamlStrEnum):
     MAVEN = "maven"
     NPM = "npm"
     PYPI = "pypi"
+    REPO = "repo"
     RPM = "rpm"
