@@ -1,33 +1,29 @@
 """
 Hoppr Network utility functions
 """
-
-from typing import Optional
-
 import requests
 
 from requests.auth import HTTPBasicAuth
 
-from hoppr.configs.credentials import Credentials
 from hoppr.exceptions import HopprLoadDataError
-from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.models.credentials import CredentialRequiredService, Credentials
 from hoppr.utils import load_string
 
 
-def load_url(url: str, creds: Optional[CredObject] = None):
+def load_url(url: str):
     """
     Load config content (either json or yml) from a url into a dict
     """
-    if creds is None:
-        creds = Credentials.find_credentials(url)
+    creds = Credentials.find(url)
 
     response = None
     if creds is not None:
         authorization_headers = {
-            "PRIVATE-TOKEN": creds.password,
+            "PRIVATE-TOKEN": creds.password.get_secret_value(),
             "Authorization": f"Bearer {creds.password}",
         }
-        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password)
+
+        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password.get_secret_value())
         response = requests.get(url, auth=basic_auth, headers=authorization_headers, timeout=60)
     else:
         response = requests.get(url, timeout=60)
@@ -54,16 +50,16 @@ def load_url(url: str, creds: Optional[CredObject] = None):
     return None  # pragma: no cover
 
 
-def download_file(url, dest, creds=None):
+def download_file(url: str, dest: str, creds: CredentialRequiredService | None = None):
     """
     Download content from a url into a file
     """
     if creds is None:
-        creds = Credentials.find_credentials(url)
+        creds = Credentials.find(url)
 
     basic_auth = None
     if creds is not None:
-        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password)
+        basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password.get_secret_value())
 
     response = requests.get(url, auth=basic_auth, allow_redirects=True, stream=True, verify=True, timeout=60)
 
