@@ -6,36 +6,31 @@ from __future__ import annotations
 import importlib
 import inspect
 
+from abc import ABCMeta
 from pathlib import Path
-from typing import Any
+from types import ModuleType
+from typing import TYPE_CHECKING, Any, Type
 
-import yaml
+from ruamel.yaml import YAML
+from ruamel.yaml.parser import ParserError as YAMLParserError
+from ruamel.yaml.scanner import ScannerError as YAMLScannerError
 
-from yaml.parser import ParserError as YAMLParserError
-from yaml.scanner import ScannerError as YAMLScannerError
-
-from hoppr.context import Context
 from hoppr.exceptions import HopprLoadDataError, HopprPluginError
 
+if TYPE_CHECKING:
+    from hoppr.base_plugins.hoppr import HopprPlugin
+    from hoppr.models import HopprContext
 
-def _class_in_module(obj, module):
+
+def _class_in_module(cls_type: ABCMeta, plugin_module: ModuleType):
     """
     Determines if the specified object is a class
     defined in the module
     """
-    if not inspect.isclass(obj):
-        return False
-
-    module_source_string = inspect.getsource(module)
-    class_source_string = inspect.getsource(obj)
-
-    if class_source_string not in module_source_string:
-        return False
-
-    return True
+    return inspect.isclass(cls_type) and cls_type.__module__ == plugin_module.__name__
 
 
-def plugin_class(plugin_name):
+def plugin_class(plugin_name: str) -> Type[HopprPlugin]:
     """
     return a concrete class of an object defined by a plugin name
 
@@ -43,21 +38,20 @@ def plugin_class(plugin_name):
     will be instaniated using a default constructor (i.e., one with no parameters).
     """
     try:
-        plugin = importlib.import_module(plugin_name)
+        plugin_module = importlib.import_module(name=plugin_name)
     except ModuleNotFoundError as mnfe:
         raise ModuleNotFoundError(f"Unable to locate plug-in {plugin_name}: {mnfe}") from mnfe
 
     plugin_cls = None
 
-    for name, obj in inspect.getmembers(plugin):
-        if _class_in_module(obj, plugin):
-
+    for cls_name, cls_type in inspect.getmembers(plugin_module, inspect.isclass):
+        if _class_in_module(cls_type, plugin_module):
             if plugin_cls is not None:
                 raise HopprPluginError(
-                    f"Multiple candidate classes defined in {plugin_name}: " + f"{plugin_cls.__name__}, {name}"
+                    f"Multiple candidate classes defined in {plugin_name}: {plugin_cls.__name__}, {cls_name}"
                 )
 
-            plugin_cls = obj
+            plugin_cls = cls_type
 
     if plugin_cls is None:
         raise HopprPluginError(f"No class definition found in in {plugin_name}.")
@@ -65,7 +59,7 @@ def plugin_class(plugin_name):
     return plugin_cls
 
 
-def plugin_instance(plugin_name: str, context: Context, config: Any = None):
+def plugin_instance(plugin_name: str, context: HopprContext, config: Any = None):
     """
     Create an instance of an object defined by a plugin name
 
@@ -90,7 +84,9 @@ def load_string(contents: str) -> dict | list | None:
 
     try:
         # Applicable to both YAML and JSON formats since valid JSON data is also valid YAML
-        loaded_contents = yaml.safe_load(contents)
+        yaml = YAML(typ="safe", pure=True)
+        contents = contents.replace("\t", "  ")
+        loaded_contents = yaml.load(contents)
 
         # yaml.safe_load will sometimes return a single string rather than the required structure
         if isinstance(loaded_contents, str):
@@ -126,33 +122,34 @@ def dedup_list(list_in: list[Any]) -> list[Any]:
     return list(dict.fromkeys(list_in)) if list_in is not None else []
 
 
-def obscure_passwords(command_list, lst):
+def obscure_passwords(command_list: list[str], sensitive_args: list[str] | None = None) -> str:
     """
     Returns an input string with any specified passwords hidden
     """
 
-    command = ""
+    password_list: list[str] = sensitive_args if sensitive_args is not None else []
+    obscured_command_list: list[str] = []
+
     for arg in command_list:
-        if len(command) > 0:
-            command += " "
+        # Quote arguments that contain spaces
         if " " in arg:
-            command += f'"{arg}"'
-        else:
-            command += arg
+            arg = f'"{arg}"'
 
-    if lst is not None:
-        for password in lst:
-            if password is not None:
-                command = command.replace(password, "<PASSWORD HIDDEN>")
+        # Replace password string(s) in argument
+        for password in password_list:
+            if password is not None and len(password) > 0:
+                arg = arg.replace(password, "[masked]")
 
-    return command
+        obscured_command_list.append(arg)
+
+    return " ".join(obscured_command_list)
 
 
 def remove_empty(directory: Path) -> set[Path]:
     """
     Removes empty folders given the directory including parent folders
     """
-    deleted = set()
+    deleted: set[Path] = set()
 
     if not directory.exists():
         raise FileNotFoundError()
